* scal 0.3.0 (2015-11-27)

    * Can now be called as `python -m scal ARGS`.
    * Generated code is to be compiled with LuaLaTeX (was XeLaTeX before).
    * French examples: Replace "Vacances de Noël" by "Vacances de fin d'année"

    -- Louis Paternault <spalax@gresille.org>

* scal 0.2.1 (2015-06-13)

    * Python3.5 support
    * Minor improvements on generated calendar
    * [doc] Updated French examples
    * Several minor improvements to setup, test and documentation.

    -- Louis Paternault <spalax@gresille.org>

* scal 0.2.0 (2015-03-15)

    * First published version.

    -- Louis Paternault <spalax@gresille.org>
